@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * Bonobo control frame object.
  *
  * Authors:
@@ -270,7 +270,6 @@ bonobo_control_frame_create_socket (BonoboControlFrame *control_frame)
 /**
  * bonobo_control_frame_construct:
  * @control_frame: The #BonoboControlFrame object to be initialized.
- * @corba_control_frame: A CORBA object for the Bonobo_ControlFrame interface.
  * @ui_container: A CORBA object for the UIContainer for the container application.
  *
  * Initializes @control_frame with the parameters.
@@ -337,8 +336,15 @@ bonobo_control_frame_destroy (GtkObject *object)
 
 	gtk_widget_destroy (control_frame->priv->container);
 
-	if (control_frame->priv->control != CORBA_OBJECT_NIL)
+	if (control_frame->priv->control != CORBA_OBJECT_NIL) {
+		CORBA_Environment ev;
+
+		CORBA_exception_init (&ev);
+		Bonobo_Control_setFrame (control_frame->priv->control,
+					 CORBA_OBJECT_NIL, &ev);
+		CORBA_exception_free (&ev);
 		bonobo_object_release_unref (control_frame->priv->control, NULL);
+	}
 	control_frame->priv->control = CORBA_OBJECT_NIL;
 
 	if (control_frame->priv->socket) {
@@ -822,7 +828,14 @@ bonobo_control_frame_get_propbag (BonoboControlFrame  *control_frame)
 
 /**
  * bonobo_control_frame_get_control_property_bag:
- */
+ * @control_frame: the control frame
+ * @ev: CORBA exception environment
+ * 
+ * This retrives a Bonobo_PropertyBag reference from its
+ * associated Bonobo Control
+ *
+ * Return value: CORBA property bag reference or CORBA_OBJECT_NIL
+ **/
 Bonobo_PropertyBag
 bonobo_control_frame_get_control_property_bag (BonoboControlFrame *control_frame,
 					       CORBA_Environment  *ev)
