@@ -1,5 +1,5 @@
 /* -*- mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * Bonobo control object
  *
  * Author:
@@ -110,7 +110,7 @@ bonobo_control_windowid_from_x11 (guint32 x11_id)
 /*
  * This callback is invoked when the plug is unexpectedly destroyed by
  * way of its associated X window dying.  This usually indicates that
- * the contaier application has died.  This callback is _not_ invoked
+ * the container application has died.  This callback is _not_ invoked
  * if the BonoboControl is destroyed normally, i.e. the user unrefs
  * the BonoboControl away.
  */
@@ -343,10 +343,10 @@ impl_Bonobo_Control_setWindowId (PortableServer_Servant  servant,
 		control->priv->destroy_idle_id = gtk_idle_add (
 			idle_destroy_socket, control);
 
-		gtk_signal_connect (GTK_OBJECT (local_socket),
-				    "destroy",
-				    remove_destroy_idle,
-				    control);
+		gtk_signal_connect_while_alive (GTK_OBJECT (local_socket),
+						"destroy",
+						remove_destroy_idle,
+						control, GTK_OBJECT (control));
 
 
 		gtk_box_pack_end (GTK_BOX (socket_parent),
@@ -539,7 +539,7 @@ bonobo_control_construct (BonoboControl  *control,
 	gtk_object_ref (GTK_OBJECT (widget));
 	gtk_object_sink (GTK_OBJECT (widget));
 
-	control->priv->ui_component = bonobo_ui_component_new_default ();
+	control->priv->ui_component = NULL;
 	control->priv->propbag = NULL;
 
 	return control;
@@ -591,10 +591,8 @@ bonobo_control_get_widget (BonoboControl *control)
  *
  * Sets whether or not the control handles menu/toolbar merging
  * automatically.  If automerge is on, the control will automatically
- * create its menus and toolbars when it is activated and destroy them
- * when it is deactivated.  The menus and toolbars which it merges are
- * specified with bonobo_control_set_menus() and
- * bonobo_control_set_toolbars().
+ * register its BonoboUIComponent with the remote BonoboUIContainer
+ * when it is activated.
  */
 void
 bonobo_control_set_automerge (BonoboControl *control,
@@ -603,6 +601,9 @@ bonobo_control_set_automerge (BonoboControl *control,
 	g_return_if_fail (BONOBO_IS_CONTROL (control));
 
 	control->priv->automerge = automerge;
+
+	if (automerge && !control->priv->ui_component)
+		control->priv->ui_component = bonobo_ui_component_new_default ();
 }
 
 /**
@@ -637,16 +638,18 @@ bonobo_control_destroy (GtkObject *object)
 		bonobo_object_unref (BONOBO_OBJECT (control->priv->propbag));
 	control->priv->propbag = NULL;
 
-	if (control->priv->active)
-		Bonobo_ControlFrame_activated (control->priv->control_frame,
-					       FALSE, &ev);
-
-	CORBA_Object_release (control->priv->control_frame, &ev);
+	if (control->priv->control_frame != CORBA_OBJECT_NIL) {
+		if (control->priv->active)
+			Bonobo_ControlFrame_activated (control->priv->control_frame,
+						       FALSE, &ev);
+		
+		CORBA_Object_release (control->priv->control_frame, &ev);
+	}
 
 	CORBA_exception_free (&ev);
 
 	/*
-	 * If we have a UIHandler, destroy it.
+	 * If we have a UIComponent, destroy it.
 	 */
 	if (control->priv->ui_component != NULL) {
 		bonobo_ui_component_unset_container (control->priv->ui_component);
@@ -706,7 +709,10 @@ bonobo_control_set_control_frame (BonoboControl *control, Bonobo_ControlFrame co
 	if (control->priv->control_frame != CORBA_OBJECT_NIL)
 		CORBA_Object_release (control->priv->control_frame, &ev);
 	
-	control->priv->control_frame = CORBA_Object_duplicate (control_frame, &ev);
+	if (control_frame == CORBA_OBJECT_NIL)
+		control->priv->control_frame = CORBA_OBJECT_NIL;
+	else
+		control->priv->control_frame = CORBA_Object_duplicate (control_frame, &ev);
 	
 	CORBA_exception_free (&ev);
 
@@ -719,7 +725,7 @@ bonobo_control_set_control_frame (BonoboControl *control, Bonobo_ControlFrame co
  * being retrieved.
  *
  * Returns: The Bonobo_ControlFrame CORBA object associated with @control, this is
- * a CORBA_object_duplicated object.  You need to CORBA_free it when you are
+ * a CORBA_Object_duplicated object.  You need to CORBA_Object_release it when you are
  * done with it.
  */
 Bonobo_ControlFrame
@@ -748,6 +754,9 @@ bonobo_control_get_ui_component (BonoboControl *control)
 {
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), NULL);
 
+	if (!control->priv->ui_component)
+		control->priv->ui_component = bonobo_ui_component_new_default ();
+
 	return control->priv->ui_component;
 }
 
@@ -808,6 +817,7 @@ bonobo_control_get_properties (BonoboControl *control)
  * bonobo_control_get_ambient_properties:
  * @control: A #BonoboControl which is bound to a remote
  * #BonoboControlFrame.
+ * @ev: CORBA exception environment.
  *
  * Returns: A #Bonobo_PropertyBag bound to the bag of ambient
  * properties associated with this #Control's #ControlFrame.
@@ -848,7 +858,6 @@ bonobo_control_get_ambient_properties (BonoboControl     *control,
 
 /**
  * bonobo_control_get_remote_ui_container:
- *
  * @control: A BonoboControl object which is associated with a remote
  * ControlFrame.
  *
@@ -858,7 +867,7 @@ Bonobo_UIContainer
 bonobo_control_get_remote_ui_container (BonoboControl *control)
 {
 	CORBA_Environment  ev;
-	Bonobo_UIContainer ui_component;
+	Bonobo_UIContainer ui_container;
 
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), CORBA_OBJECT_NIL);
 
@@ -867,13 +876,13 @@ bonobo_control_get_remote_ui_container (BonoboControl *control)
 
 	CORBA_exception_init (&ev);
 
-	ui_component = Bonobo_ControlFrame_getUIHandler (control->priv->control_frame, &ev);
+	ui_container = Bonobo_ControlFrame_getUIHandler (control->priv->control_frame, &ev);
 
 	bonobo_object_check_env (BONOBO_OBJECT (control), control->priv->control_frame, &ev);
 
 	CORBA_exception_free (&ev);
 
-	return ui_component;
+	return ui_container;
 }
 
 /**
@@ -956,9 +965,9 @@ bonobo_control_init (BonoboControl *control)
 }
 
 BONOBO_X_TYPE_FUNC_FULL (BonoboControl, 
-			   Bonobo_Control,
-			   PARENT_TYPE,
-			   bonobo_control);
+			 Bonobo_Control,
+			 PARENT_TYPE,
+			 bonobo_control);
 
 void
 bonobo_control_set_property (BonoboControl       *control,
