@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * bonobo-generic-factory.h: a GenericFactory object.
  *
  * Author:
@@ -26,6 +26,63 @@ BEGIN_GNOME_DECLS
 #define BONOBO_IS_GENERIC_FACTORY(o)       (GTK_CHECK_TYPE ((o), BONOBO_GENERIC_FACTORY_TYPE))
 #define BONOBO_IS_GENERIC_FACTORY_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_GENERIC_FACTORY_TYPE))
 
+typedef struct _BonoboGenericFactoryPrivate BonoboGenericFactoryPrivate;
+typedef struct _BonoboGenericFactory        BonoboGenericFactory;
+
+typedef BonoboObject * (*BonoboGenericFactoryFn)(BonoboGenericFactory *Factory, void *closure);
+typedef BonoboObject * (*GnomeFactoryCallback)(BonoboGenericFactory *factory, const char *component_id, gpointer closure);
+					
+struct _BonoboGenericFactory {
+	BonoboObject base;
+
+	/* The function factory */
+	BonoboGenericFactoryFn factory; /* compat reasons only */
+	GnomeFactoryCallback   factory_cb;
+	gpointer               factory_closure;
+
+	/* The component_id for this generic factory */
+	char *oaf_iid;
+};
+
+typedef struct {
+	BonoboObjectClass parent_class;
+
+	/* Virtual methods */
+	BonoboObject *(*new_generic) (BonoboGenericFactory *c_factory,
+				      const char           *component_id);
+} BonoboGenericFactoryClass;
+
+GtkType               bonobo_generic_factory_get_type  (void);
+
+CORBA_Object          bonobo_generic_factory_corba_object_create (
+	BonoboObject *object,
+	gpointer      shlib_id);
+
+BonoboGenericFactory *bonobo_generic_factory_new (
+	const char            *oaf_iid,
+	BonoboGenericFactoryFn factory,
+	gpointer               user_data);
+
+BonoboGenericFactory *bonobo_generic_factory_new_multi (
+	const char            *oaf_iid,
+	GnomeFactoryCallback   factory_cb,
+	gpointer               data);
+
+BonoboGenericFactory *bonobo_generic_factory_construct (
+	const char            *oaf_iid,
+	BonoboGenericFactory  *c_factory,
+	CORBA_Object           corba_factory,
+	BonoboGenericFactoryFn factory,
+	GnomeFactoryCallback   factory_cb,
+	gpointer               user_data);
+
+void bonobo_generic_factory_set (
+	BonoboGenericFactory  *c_factory,
+	BonoboGenericFactoryFn factory,
+	void                  *data);
+
+POA_GNOME_ObjectFactory__epv *bonobo_generic_factory_get_epv (void);
+
 #define BONOBO_OAF_FACTORY(oafiid, descr, version, fn, data)                  \
 int main (int argc, char *argv [])                                            \
 {                                                                             \
@@ -66,63 +123,6 @@ int main (int argc, char *argv [])                                            \
 	return 0;                                                             \
 }                                                                             
 
-typedef struct _BonoboGenericFactoryPrivate BonoboGenericFactoryPrivate;
-typedef struct _BonoboGenericFactory        BonoboGenericFactory;
-
-typedef BonoboObject * (*BonoboGenericFactoryFn)(BonoboGenericFactory *Factory, void *closure);
-typedef BonoboObject * (*GnomeFactoryCallback)(BonoboGenericFactory *factory, const char *component_id, gpointer closure);
-					
-struct _BonoboGenericFactory {
-	BonoboObject base;
-
-	/* The function factory */
-	BonoboGenericFactoryFn factory; /* compat reasons only */
-	GnomeFactoryCallback   factory_cb;
-	gpointer               factory_closure;
-
-	/* The component_id for this generic factory */
-	char *oaf_iid;
-};
-
-typedef struct {
-	BonoboObjectClass parent_class;
-
-	/* Virtual methods */
-	BonoboObject *(*new_generic) (BonoboGenericFactory *c_factory,
-				      const char           *component_id);
-} BonoboGenericFactoryClass;
-
-GtkType               bonobo_generic_factory_get_type  (void);
-
-CORBA_Object          bonobo_generic_factory_corba_object_create (
-	BonoboObject *object,
-	gpointer      shlib_id);
-
-BonoboGenericFactory *bonobo_generic_factory_new (
-	const char            *component_id,
-	BonoboGenericFactoryFn factory,
-	gpointer               user_data);
-
-BonoboGenericFactory *bonobo_generic_factory_new_multi (
-	const char            *component_id,
-	GnomeFactoryCallback   factory_cb,
-	gpointer               data);
-
-BonoboGenericFactory *bonobo_generic_factory_construct (
-	const char            *component_id,
-	BonoboGenericFactory  *c_factory,
-	CORBA_Object           corba_factory,
-	BonoboGenericFactoryFn factory,
-	GnomeFactoryCallback   factory_cb,
-	void                  *data);
-
-void bonobo_generic_factory_set (
-	BonoboGenericFactory  *c_factory,
-	BonoboGenericFactoryFn factory,
-	void                  *data);
-
-POA_GNOME_ObjectFactory__epv *bonobo_generic_factory_get_epv (void);
-
 END_GNOME_DECLS
 
 #endif
