@@ -1,10 +1,11 @@
-/**
+/*
  * bonobo-property-bag-client.c: C sugar for property bags.
  *
- * Author:
- *   Nat Friedman (nat@nat.org)
+ * Authors:
+ *   Nat Friedman  (nat@ximian.com)
+ *   Michael Meeks (michael@ximian.com)
  *
- * Copyright 1999, Helix Code, Inc.
+ * Copyright 1999, 2001 Ximian, Inc.
  */
 #include <config.h>
 #include <stdarg.h>
@@ -15,14 +16,15 @@
  * bonobo_property_bag_client_get_properties:
  * @pb: A #Bonobo_PropertyBag      which is bound to a remote
  * #Bonobo_PropertyBag.
+ * @ev: optional CORBA exception environment or NULL
  *
  * Returns: A #GList filled with #Bonobo_Property CORBA object
  * references for all of the properties stored in the remote
  * #BonoboPropertyBag.
  */
 GList *
-bonobo_property_bag_client_get_properties (Bonobo_PropertyBag       pb,
-					   CORBA_Environment       *ev)
+bonobo_property_bag_client_get_properties (Bonobo_PropertyBag pb,
+					   CORBA_Environment *ev)
 {
 	Bonobo_PropertyList  *props;
 	GList		    *prop_list;
@@ -125,6 +127,7 @@ bonobo_property_bag_client_free_properties (GList *list)
  * bonobo_property_bag_client_get_property_names:
  * @pb: A #Bonobo_PropertyBag      which is bound to a remote
  * #Bonobo_PropertyBag.
+ * @ev: optional CORBA exception environment or NULL
  *
  * This function exists as a convenience, so that you don't have to
  * iterate through all of the #Bonobo_Property objects in order to get
@@ -136,8 +139,8 @@ bonobo_property_bag_client_free_properties (GList *list)
  * the properties stored in the remote #BonoboPropertyBag.
  */
 GList *
-bonobo_property_bag_client_get_property_names (Bonobo_PropertyBag       pb,
-					       CORBA_Environment       *ev)
+bonobo_property_bag_client_get_property_names (Bonobo_PropertyBag pb,
+					       CORBA_Environment *ev)
 {
 	Bonobo_PropertyNames  *names;
 	GList		     *name_list;
@@ -180,12 +183,14 @@ bonobo_property_bag_client_get_property_names (Bonobo_PropertyBag       pb,
 
 /**
  * bonobo_property_bag_client_get_property:
- * @pb: A Bonobo_PropertyBag      which is associated with a remote
+ * @pb: A Bonobo_PropertyBag which is associated with a remote
  * BonoboPropertyBag.
  * @name: A string containing the name of the property which is to
  * be fetched.
+ * @ev: optional CORBA exception environment or NULL
  *
- * Returns: A #Bonobo_Property CORBA object reference for the
+ * Returns: A #Bonobo_Property CORBA object reference corresponding
+ * to the requested property.
  *
  */
 Bonobo_Property
@@ -223,11 +228,12 @@ bonobo_property_bag_client_get_property (Bonobo_PropertyBag       pb,
 
 /**
  * bonobo_property_bag_client_persist:
- * @pb: A #Bonobo_PropertyBag      object which is bound to a remote
+ * @pb: A #Bonobo_PropertyBag object which is bound to a remote
  * #Bonobo_PropertyBag server.
  * @stream: A #BonoboStream into which the data in @pb will be written.
+ * @ev: optional CORBA exception environment or NULL
  *
- * Reads the property data stored in the #Bonobo_Property_bag to which
+ * Reads the property data stored in the #Bonobo_PropertyBag to which
  * @pb is bound and streams it into @stream.  The typical use for
  * this function is to save the property data for a given Bonobo
  * Control into a persistent store to which @stream is attached.
@@ -266,7 +272,14 @@ bonobo_property_bag_client_persist (Bonobo_PropertyBag       pb,
 
 /**
  * bonobo_property_bag_client_depersist:
- */
+ * @pb: the property bag to persist
+ * @stream: the stream to persist to
+ * @ev: optional CORBA exception environment or NULL
+ * 
+ *  Serializes the property bag @pb to the @stream,
+ * using the PersistStream interface associated with the
+ * PropertyBag.
+ **/
 void
 bonobo_property_bag_client_depersist (Bonobo_PropertyBag       pb,
 				      Bonobo_Stream            stream,
@@ -307,7 +320,14 @@ bonobo_property_bag_client_depersist (Bonobo_PropertyBag       pb,
 
 /**
  * bonobo_property_bag_client_get_property_type:
- */
+ * @pb: the property bag
+ * @propname: the property name
+ * @ev: optional CORBA exception environment or NULL
+ * 
+ * Finds the typecode associated with the property in @pb of name @propname
+ * 
+ * Return value: the TypeCode for property @name or CORBA_OBJECT_NIL
+ **/
 CORBA_TypeCode
 bonobo_property_bag_client_get_property_type (Bonobo_PropertyBag       pb,
 					      const char              *propname,
@@ -334,6 +354,7 @@ bonobo_property_bag_client_get_property_type (Bonobo_PropertyBag       pb,
 			g_warning ("prop is NIL");
 			CORBA_exception_free (&tmp_ev);
 		}
+		return (CORBA_TypeCode) TC_null;
 	}
 
 	tc = Bonobo_Property_getType (prop, real_ev);
@@ -435,7 +456,11 @@ bonobo_property_bag_client_get_field_##type (Bonobo_PropertyBag       pb,	\
 	if (any == NULL)							\
 		return 0.0;							\
 										\
-	g_return_val_if_fail (any->_type->kind == tk, (def));			\
+        if (any->_type->kind != tk) {                                           \
+                g_warning ("Assertion `any->_type->kind == tk' failed");        \
+                CORBA_any__free (any, NULL, TRUE);                              \
+                return (def);                                                   \
+        }                                                                       \
 										\
 	d = *(corbatype *) any->_value;						\
 										\
@@ -468,7 +493,11 @@ bonobo_property_bag_client_get_field_string (Bonobo_PropertyBag       pb,
 	if (any == NULL)
 		return NULL;
 
-	g_return_val_if_fail (any->_type->kind == CORBA_tk_string, NULL);
+	if (any->_type->kind != CORBA_tk_string) {
+		g_warning ("assertion failed: `any->_type->kind == CORBA_tk_string'");
+		CORBA_any__free (any, NULL, TRUE);
+		return NULL;
+	}
 
 	str = g_strdup (*(char **) any->_value);
 
@@ -511,6 +540,17 @@ MAKE_BONOBO_PROPERTY_BAG_CLIENT_PAIR(any,      BonoboArg *);
 /*
  * Setting property values.
  */
+
+/**
+ * bonobo_property_bag_client_set_value_any:
+ * @pb: the property bag
+ * @propname: name of property to set
+ * @value: value to set it to.
+ * @ev: optional CORBA exception environment or NULL
+ * 
+ * This function sets the value of the property with name
+ * @propname in @pb to @value.
+ **/
 void
 bonobo_property_bag_client_set_value_any (Bonobo_PropertyBag       pb,
 					  const char              *propname,
@@ -598,6 +638,18 @@ bonobo_property_bag_client_set_value_string (Bonobo_PropertyBag       pb,
 /*
  * Querying other fields and flags.
  */
+
+/**
+ * bonobo_property_bag_client_get_docstring:
+ * @pb: the property bag
+ * @propname: the property name
+ * @ev: optional CORBA exception environment or NULL
+ * 
+ * This function retrieves the documentation string associated
+ * with the property.
+ * 
+ * Return value: the doc string.
+ **/
 char *
 bonobo_property_bag_client_get_docstring (Bonobo_PropertyBag       pb,
 					  const char              *propname,
@@ -644,6 +696,14 @@ bonobo_property_bag_client_get_docstring (Bonobo_PropertyBag       pb,
 	return (char *) docstr;
 }
 
+/**
+ * bonobo_property_bag_client_get_flags:
+ * @pb: the property bag
+ * @propname: the property's name
+ * @ev: optional CORBA exception environment or NULL
+ * 
+ * Return value: the flags associated with this property
+ **/
 BonoboPropertyFlags
 bonobo_property_bag_client_get_flags (Bonobo_PropertyBag       pb,
 				      const char              *propname,
@@ -691,6 +751,20 @@ bonobo_property_bag_client_get_flags (Bonobo_PropertyBag       pb,
 		bonobo_property_bag_client_set_value##gt (pb, name, (CORBA##corbat) va_arg (args, ##ansip), ev);\
 		break;
 
+/**
+ * bonobo_property_bag_client_setv:
+ * @pb: the property bag
+ * @ev: optional CORBA exception environment or NULL
+ * @first_arg: first argument name
+ * @var_args: list of subsequent name / value pairs
+ * 
+ * This function uses the TypeCode data extracted from the
+ * @pb to determine how it walks its stack. This function
+ * provides the grunt implementation for other var-arg
+ * functions like bonobo_widget_set_property
+ * 
+ * Return value: an error string on error or NULL on success.
+ **/
 char *
 bonobo_property_bag_client_setv (Bonobo_PropertyBag       pb,
 				 CORBA_Environment       *ev,
@@ -745,6 +819,20 @@ bonobo_property_bag_client_setv (Bonobo_PropertyBag       pb,
 		    bonobo_property_bag_client_get_value##gt (pb, name, ev);	\
 		break;
 
+/**
+ * bonobo_property_bag_client_getv:
+ * @pb: the property bag
+ * @ev: optional CORBA exception environment or NULL
+ * @first_arg: first argument name
+ * @var_args: list of subsequent name / value pairs
+ * 
+ * This function uses the TypeCode data extracted from the
+ * @pb to determine how it walks its stack. This function
+ * provides the grunt implementation for other var-arg
+ * functions like bonobo_widget_get_property.
+ * 
+ * Return value: an error string on error or NULL on success.
+ **/
 char *
 bonobo_property_bag_client_getv (Bonobo_PropertyBag pb,
 				 CORBA_Environment *ev,
@@ -793,5 +881,3 @@ bonobo_property_bag_client_getv (Bonobo_PropertyBag pb,
 	return NULL;
 }
 #undef RECEIVE
-
-
