@@ -1,12 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /**
- * b-object.c: B Unknown interface base implementation
+ * bonobo-xobject.c: B Unknown interface base implementation
  *
  * Authors:
- *   Miguel de Icaza (miguel@kernel.org)
- *   Michael Meeks (michael@helixcode.com)
+ *   Michael Meeks (michael@ximian.com)
  *
- * Copyright 1999,2000 Helix Code, Inc.
+ * Copyright 2000 Ximian, Inc.
  */
 
 #include <config.h>
@@ -90,7 +89,7 @@ corba_cleanup (BonoboXObject *x_object)
 			
 	if (klass->poa_fini_fn)
 		klass->poa_fini_fn (servant, &ev);
-	else /* Actualy quicker and nicer */
+	else /* Actually quicker and nicer */
 		PortableServer_ServantBase__fini (servant, &ev);
 			
 	CORBA_free (oid);
@@ -290,6 +289,19 @@ bonobo_x_object_get_type (void)
 	return type;
 }
 
+/**
+ * bonobo_x_type_setup:
+ * @type: The type to initialize
+ * @init_fn: the POA_init function for the CORBA interface or NULL
+ * @fini_fn: NULL or a custom POA free fn.
+ * @epv_struct_offset: the offset in the class structure where the epv is or 0
+ * 
+ *   This function initializes a type derived from BonoboXObject, such that
+ * when you instantiate a new object of this type with gtk_type_new the
+ * CORBA object will be correctly created and embedded.
+ * 
+ * Return value: TRUE on success, FALSE on error.
+ **/
 gboolean
 bonobo_x_type_setup (GtkType            type,
 		     BonoboXObjectPOAFn init_fn,
@@ -361,6 +373,21 @@ bonobo_x_type_setup (GtkType            type,
 	return TRUE;
 }
 
+/**
+ * bonobo_x_type_unique:
+ * @parent_type: the parent Gtk Type
+ * @init_fn: a POA initialization function
+ * @fini_fn: a POA finialization function or NULL
+ * @epv_struct_offset: the offset into the struct that the epv
+ * commences at, or 0 if we are inheriting a plain Gtk Object
+ * from a BonoboXObject, adding no new CORBA interfaces
+ * @info: the standard GtkTypeInfo.
+ * 
+ * This function is the main entry point for deriving bonobo
+ * server interfaces.
+ * 
+ * Return value: the constructed Gtk Type.
+ **/
 GtkType
 bonobo_x_type_unique (GtkType            parent_type,
 		      BonoboXObjectPOAFn init_fn,
@@ -390,6 +417,17 @@ bonobo_x_type_unique (GtkType            parent_type,
 		return 0;
 }
 
+/**
+ * bonobo_x_object:
+ * @p: a pointer to something
+ * 
+ * This function can be passed a BonoboXObject * or a
+ * PortableServer_Servant, and it will return a BonoboXObject *.
+ * It also can convert a CORBA_Object to a BonoboXObject in
+ * some circumstances, but this behavior is broken conceptually.
+ * 
+ * Return value: a BonoboXObject or NULL.
+ **/
 BonoboXObject *
 bonobo_x_object (gpointer p)
 {
